package com.zhiyun.framework.web;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.zhiyun.common.enums.UserStatus;
import com.zhiyun.common.exception.UserException;
import com.zhiyun.project.system.domain.dto.LoginUser;
import com.zhiyun.project.system.domain.entity.SysUser;
import com.zhiyun.project.system.service.ISysUserService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.core.userdetails.UserDetails;
import org.springframework.security.core.userdetails.UserDetailsService;
import org.springframework.security.core.userdetails.UsernameNotFoundException;
import org.springframework.stereotype.Service;

/**
 * 用户验证处理
 *
 * @author ruoyi
 */
@Slf4j
@Service
public class UserDetailsServiceImpl implements UserDetailsService {

    @Autowired
    private ISysUserService userService;

    @Override
    public UserDetails loadUserByUsername(String username) throws UsernameNotFoundException {
        SysUser user = userService.getOne(new QueryWrapper<SysUser>().eq("user_name", username));
        if (user == null) {
            log.error("登录用户：{} 不存在.", username);
            throw new UserException("登录用户：" + username + " 不存在");
        } else if (UserStatus.DISABLE.getCode().equals(user.getStatus())) {
            log.error("登录用户：{} 已被停用.", username);
            throw new UserException("对不起，您的账号：" + username + " 已停用");
        }
        return new LoginUser(user);
    }

}
