package com.zhiyun.project.project.controller;

import com.zhiyun.common.model.ApiResult;
import com.zhiyun.common.model.BaseBody;
import com.zhiyun.common.model.TableResult;
import com.zhiyun.project.common.BaseController;
import com.zhiyun.project.project.domain.entity.Company;
import com.zhiyun.project.project.service.CompanyService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

/**
 * 公司 前端控制器
 *
 * @author zhiyun
 * @since 2023-05-24
 */
@RestController
@RequestMapping("/company")
public class CompanyController extends BaseController {
    @Autowired
    private CompanyService companyService;

    /**
     * 公司筛选项
     */
    @GetMapping("/listCompanyOptions")
    public ApiResult listCompanyOptions() {
        return ApiResult.success(companyService.listCompanyOptions());
    }

    /**
     * 获取公司数据
     */
    @GetMapping("/listPage")
    public TableResult listPage(BaseBody body) {
        return TableResult.getTableResult(companyService.page(body.getPage()));
    }

    /**
     * 添加公司
     */
    @PreAuthorize("@ss.checkAdmin()")
    @PostMapping("/save")
    public ApiResult save(@RequestBody Company entity) {
        return toApiResult(companyService.save(entity));
    }

    /**
     * 修改公司
     */
    @PreAuthorize("@ss.checkAdmin()")
    @PutMapping("/modify")
    public ApiResult modify(@RequestBody Company entity) {
        return toApiResult(companyService.updateById(entity));
    }

    /**
     * 删除公司
     */
    @PreAuthorize("@ss.checkAdmin()")
    @DeleteMapping("/remove/{cpyid}")
    public ApiResult remove(@PathVariable Integer cpyid) {
        return toApiResult(companyService.removeById(cpyid));
    }

}

