package com.zhiyun.project.project.controller;

import com.zhiyun.common.model.ApiResult;
import com.zhiyun.common.model.TableResult;
import com.zhiyun.framework.web.SysPermissionService;
import com.zhiyun.project.common.BaseController;
import com.zhiyun.project.project.domain.body.DeviceBody;
import com.zhiyun.project.project.domain.entity.Device;
import com.zhiyun.project.project.service.DeviceService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import java.util.Arrays;
import java.util.List;
import java.util.UUID;
import java.util.stream.Collectors;

/**
 * 设备表 前端控制器
 *
 * @author zhiyun
 * @since 2023-05-24
 */
@RestController
@RequestMapping("/device")
public class DeviceController extends BaseController {
    @Autowired
    private DeviceService deviceService;
    @Autowired
    private SysPermissionService sysPermissionService;

    /**
     * 查询未分配的设备
     */
    @GetMapping("/listNoAllotDevice")
    public TableResult listNoAllotDevice() {
        return TableResult.getTableResult(deviceService.listNoAllotDevice());
    }

    /**
     * 站点信息详查
     */
    @GetMapping("/listPage")
    public TableResult listPage(DeviceBody body) {
        return TableResult.getTableResult(deviceService.listPage(body));
    }

    /**
     * 站点信息详查
     */
    @GetMapping("/listDeviceOptions")
    public ApiResult listDeviceOptions() {
        return ApiResult.success(deviceService.listDeviceOptions());
    }


    /**
     * 添加设备
     */
    @PreAuthorize("@ss.checkAdmin()")
    @PostMapping("/save")
    public ApiResult saveDevice(@RequestBody Device entity) {
        entity.setDevicename(UUID.randomUUID().toString());
        return toApiResult(deviceService.save(entity));
    }

    /**
     * 修改设备基础信息
     */
    @PreAuthorize("@ss.checkAdmin()")
    @PutMapping("/modify")
    public ApiResult modify(@RequestBody Device entity) {
        sysPermissionService.checkUserDevicePerm(entity.getDevicename());
        return toApiResult(deviceService.modify(entity));
    }

    /**
     * 删除设备
     */
    @PreAuthorize("@ss.checkAdmin()")
    @DeleteMapping("/remove/{devicenames}")
    public ApiResult remove(@PathVariable String[] devicenames) {
        List<String> idList = Arrays.stream(devicenames).collect(Collectors.toList());
        sysPermissionService.checkUserDevicePerm(idList);
        return toApiResult(deviceService.remove(idList));
    }

}

