package com.zhiyun.project.project.controller;

import com.zhiyun.common.model.ApiResult;
import com.zhiyun.common.model.TableResult;
import com.zhiyun.framework.web.TokenService;
import com.zhiyun.project.common.BaseController;
import com.zhiyun.project.project.domain.body.ProjectBody;
import com.zhiyun.project.project.domain.entity.Project;
import com.zhiyun.project.project.service.ProjectService;
import com.zhiyun.project.system.domain.dto.LoginUser;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

/**
 * 项目 前端控制器
 *
 * @author zhiyun
 * @since 2023-05-24
 */
@RestController
@RequestMapping("/project")
public class ProjectController extends BaseController {
    @Autowired
    private ProjectService projectService;
    @Autowired
    TokenService tokenService;

    /**
     * 选择系统当前项目
     */
    @PostMapping("setCurrentProject")
    public ApiResult setCurrentProject(Integer pjtid) {
        LoginUser loginUser = getLoginUser();
        loginUser.setCurrentProjectId(pjtid);
        tokenService.setLoginUser(loginUser);
        return ApiResult.success();
    }

    /**
     * 获取系统当前项目
     */
    @GetMapping("getCurrentProject")
    public ApiResult getCurrentProject() {
        return ApiResult.success(projectService.getById(getLoginUser().getCurrentProjectId()));
    }

    /**
     * 分页查询项目
     */
    @GetMapping("/listPage")
    public TableResult listPage(ProjectBody body) {
        return TableResult.getTableResult(projectService.listPage(body));
    }

    /**
     * 查询所有项目
     */
    @GetMapping("/list")
    public ApiResult list() {
        return ApiResult.success(projectService.listProject());
    }

    /**
     * 添加项目
     */
    @PreAuthorize("@ss.checkAdmin()")
    @PostMapping("/save")
    public ApiResult save(@RequestBody Project entity) {
        return toApiResult(projectService.save(entity));
    }

    /**
     * 修改项目
     */
    @PreAuthorize("@ss.checkAdmin()")
    @PutMapping("/modify")
    public ApiResult modify(@RequestBody Project entity) {
        return toApiResult(projectService.updateById(entity));
    }

    /**
     * 删除项目
     */
    @PreAuthorize("@ss.checkAdmin()")
    @DeleteMapping("/remove/{pjtid}")
    public ApiResult remove(@PathVariable Integer pjtid) {
        return toApiResult(projectService.removeById(pjtid));
    }

}

