package com.zhiyun.project.project.mqtt.handler;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.zhiyun.common.utils.RabbitMQApi;
import com.zhiyun.framework.config.mqtt.MqttConstant;
import com.zhiyun.project.project.domain.dto.MqttDTO;
import com.zhiyun.project.project.domain.entity.Device;
import com.zhiyun.project.project.domain.entity.DeviceState;
import com.zhiyun.project.project.domain.entity.MqttLog;
import com.zhiyun.project.project.mqtt.TransformEntity;
import com.zhiyun.project.project.mqtt.sender.CommonSender;
import com.zhiyun.project.project.service.DeviceService;
import com.zhiyun.project.project.service.DeviceStateService;
import com.zhiyun.project.project.service.LogService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

/**
 * 普适性 设备消息处理
 *
 * @author yang xiao kun
 * create on 2021/7/26
 */
@Slf4j
@Component
public class OldHandler {
    @Autowired
    DeviceService deviceService;
    @Autowired
    private DeviceStateService deviceStateService;
    @Autowired
    CommonSender commonSender;
    @Autowired
    LogService logService;

    private static final Integer type = 2;

    public void handle(String topic, String payload) {
        //设备码
        String devicename = MqttConstant.splitOpenNum(topic);
        //解析数据
        MqttDTO mqttDTO = MqttDTO.parse(payload);

        // 1.存储日志
        JSONObject jsonObject = JSON.parseObject(payload);
        Integer code =jsonObject.getIntValue("code");
        logService.save(MqttLog.createNormal(topic, devicename, type, payload,code));

        // 2.根据报文标识代码 M 处理消息
        switch (mqttDTO.getM()) {
            //设备端注册报文
            case MqttConstant.M.REGISTER: {
                registerHandler(mqttDTO);
                break;
            }
            // 心跳数据
            case MqttConstant.M.UBI_HEARTBEAT: {
                heartbeatHandler(devicename, mqttDTO);
                break;
            }
        }
    }

    /**
     * 注册设备
     */
    public void registerHandler(MqttDTO mqttDTO) {
        //注册指令传来的设备信息
        Device device = TransformEntity.tsf2DeviceBase(mqttDTO);
        // 查询数据库中是否有此设备
        Device dbData = deviceService.getOne(new QueryWrapper<Device>().eq("devicename", device.getDevicename()));
        //saveOrUpdate根据主键ID来判断
        device.setId(dbData == null ? null : dbData.getId());

        deviceService.saveOrUpdate(device);
        // mqtt服务器注册用户
        RabbitMQApi.register(device.getMqttUsername(), device.getMqttPassword());
        // 返回处理结果
        commonSender.register(device);
    }

    /**
     * 心跳协议
     */
    public void heartbeatHandler(String devicename, MqttDTO mqttDTO) {
        DeviceState record = TransformEntity.tsf2DeviceStateRecord(devicename, mqttDTO);
        //存储记录
        deviceStateService.saveRecord(record);
        deviceStateService.saveOrUpdate(record, new QueryWrapper<DeviceState>().eq("devicename", record.getDevicename()));
    }
}
