package com.zhiyun.project.project.mqtt.sender;

import com.zhiyun.framework.config.mqtt.MqttGateway;
import com.zhiyun.project.project.domain.entity.MqttLog;
import com.zhiyun.project.project.service.LogService;
import org.checkerframework.checker.units.qual.A;
import org.eclipse.paho.client.mqttv3.MqttCallback;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;

/**
 * Mqtt消息发送者
 *
 * @author yang xiao kun
 * create on 2021/10/26
 */
@Component
public class BaseSender {

    @Resource
    private MqttGateway mqttGateway;
    @Resource
    private LogService logsService;

    private static final Integer type = 1;

    /**
     * 发送Mqtt 消息
     *
     * @param topic   主题
     * @param payload 内容
     */
    public void send(String devicename, String topic, Integer cmdid,String payload) {
        // 1. 发送 MQTT 协议消息
        mqttGateway.sendMsgToMqtt(payload, topic);


        try {
            // 等待 3 秒钟，给消息传递时间
            Thread.sleep(3000);
        } catch (InterruptedException e) {
            // 捕获异常
            e.printStackTrace();
        }

        // 根据返回日志查看是否发送成功
        if(logsService.nowLog(devicename) == null){
            logsService.save(new MqttLog(topic, devicename, type,cmdid, payload,1));
            String errBack = "{\n" +
                    " \"code\":1,\n" +
                    " \"msg\":\"发送失败，请检查设备或网络连接！\"\n" +
                    "}";
            logsService.save(MqttLog.createNormal(topic, devicename, 2, errBack,null));
        }else{
            // 2. 存储消息日志
            logsService.save(new MqttLog(topic, devicename, type,cmdid, payload,0));
        }


    }

    public void send(String devicename, String topic, String payload) {


            // 1. 发送 MQTT 协议消息
            mqttGateway.sendMsgToMqtt(payload, topic);
            // 2. 存储消息日志
            logsService.save(new MqttLog(topic, devicename, type, payload,0));

    }

}
