package com.zhiyun.project.project.service;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.zhiyun.framework.UserDataScope;
import com.zhiyun.project.project.domain.body.DeviceBody;
import com.zhiyun.project.project.domain.entity.Device;
import com.zhiyun.project.project.domain.vo.DeviceVo;
import com.zhiyun.project.project.domain.vo.SelectOptionsVo;
import com.zhiyun.project.project.mapper.DeviceMapper;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Map;

/**
 * 设备表 服务实现类
 *
 * @author zhiyun
 * @since 2023-05-24
 */
@Service
public class DeviceService extends ServiceImpl<DeviceMapper, Device> {

    /**
     * 获取未分配测区的设备
     */
    public List<DeviceVo> listNoAllotDevice() {
        return baseMapper.listNoAllotDevice();
    }

    /**
     * 站点信息详查列表
     */
    public Page<DeviceVo> listPage(DeviceBody body) {
        return baseMapper.listPage(body.getPage(), UserDataScope.getDataScopePerm(), body);
    }

    /**
     * 获取设备筛选项
     */
    public List<SelectOptionsVo> listDeviceOptions() {
        return baseMapper.listDeviceOption(UserDataScope.getDataScopePerm());
    }

    /**
     * 逻辑删除
     */
    public boolean remove(List<String> devicenames) {
        baseMapper.removeByDevicename(devicenames);
        return true;
    }

    /**
     * 修改设备信息
     */
    public boolean modify(Device device) {
        return baseMapper.updateById(device) > 0;
    }

    /**
     * 获取设备类型数量
     */
    public  List<Map<String,Integer>> getDeviceCount() {
        return baseMapper.getDeviceCount();
    }

    /**
     * 获取未分配数量
     */
    public Long noAllotNum(){
        return baseMapper.noAllotNum();
    }

}
