package com.zhiyun.project.system.controller;

import com.google.common.collect.Sets;
import com.zhiyun.common.model.ApiResult;
import com.zhiyun.common.utils.SecurityUtils;
import com.zhiyun.framework.UserDataScope;
import com.zhiyun.project.common.BaseController;
import com.zhiyun.project.system.domain.RouteBuilder;
import com.zhiyun.project.system.domain.body.LoginBody;
import com.zhiyun.project.system.domain.dto.LoginUser;
import com.zhiyun.project.system.domain.entity.SysUser;
import com.zhiyun.project.system.domain.vo.SysMenuVo;
import com.zhiyun.project.system.service.ISysMenuService;
import com.zhiyun.project.system.service.impl.SysLoginService;
import io.vavr.Tuple2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;


import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 登录验证
 *
 * @author ruoyi
 */
@RestController
public class SysLoginController extends BaseController {
    @Autowired
    private SysLoginService loginService;
    @Autowired
    private ISysMenuService menuService;

    /**
     * 登录方法
     *
     * @param loginBody 登录信息
     * @return 结果
     */
    @PostMapping("/login")
    public ApiResult login(@RequestBody LoginBody loginBody) {
        // 生成令牌
        Tuple2<String, Integer> token = loginService.login(loginBody.getUsername(), loginBody.getPassword(), loginBody.getCode(), loginBody.getUuid());
        Map<String, Object> result = new HashMap<>();
        result.put("token", token._1());
        result.put("flag", token._2());
        return ApiResult.success(result);
    }

    /**
     * 获取用户信息
     *
     * @return 用户信息
     */
    @GetMapping("getInfo")
    public ApiResult getInfo() {
        LoginUser loginUser = SecurityUtils.getLoginUser();
        SysUser user = SysUser.clearKeyWords(loginUser.getUser());
        Map<String, Object> result = new HashMap<>();
        result.put("user", user);
        result.put("roles", Sets.newHashSet(UserDataScope.isAdmin(loginUser.getUserId()) ? "admin" : "comn"));
        return ApiResult.success(result);
    }

    /**
     * 获取路由信息
     *
     * @return 路由信息
     */
    @GetMapping("getRouters")
    public ApiResult getRouters() {
        List<SysMenuVo> menus = menuService.getMenuTreeByMineId(getLoginUser().getUserId());
        return ApiResult.success(RouteBuilder.buildMenus(menus));
    }
}
