package com.zhiyun.project.system.controller;

import com.zhiyun.common.constant.UserConstants;
import com.zhiyun.common.model.ApiResult;
import com.zhiyun.project.common.BaseController;
import com.zhiyun.project.system.domain.body.SysMenuBody;
import com.zhiyun.project.system.domain.entity.SysMenu;
import com.zhiyun.project.system.service.ISysMenuService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

/**
 * 菜单信息
 *
 * @author ruoyi
 */
@RestController
@RequestMapping("/system/menu")
public class SysMenuController extends BaseController {
    @Autowired
    private ISysMenuService menuService;

    /**
     * 获取菜单列表
     */
    @PreAuthorize("@ss.checkAdmin()")
    @GetMapping("/list")
    public ApiResult list(SysMenuBody body) {
        return ApiResult.success(menuService.getMenuList(body));
    }

    /**
     * 根据菜单编号获取详细信息
     */
    @PreAuthorize("@ss.checkAdmin()")
    @GetMapping(value = "/{menuId}")
    public ApiResult getInfo(@PathVariable Long menuId) {
        return ApiResult.success(menuService.getById(menuId));
    }

    /**
     * 加载对应角色菜单列表树
     */
    @GetMapping(value = "/pjtMenuTreeSelect/{mineId}")
    public ApiResult pjtMenuTreeSelect(@PathVariable("mineId") Integer mineId) {
        return ApiResult.success(menuService.getMineMenuTreeSelect(mineId));
    }

    /**
     * 新增菜单
     */
    @PreAuthorize("@ss.checkAdmin()")
    @PostMapping
    public ApiResult add(@Validated @RequestBody SysMenu menu) {
        if (UserConstants.NOT_UNIQUE.equals(menuService.checkMenuNameUnique(menu))) {
            return ApiResult.error("新增菜单'" + menu.getMenuName() + "'失败，菜单名称已存在");
        }
        return toApiResult(menuService.save(menu));
    }

    /**
     * 修改菜单
     */
    @PreAuthorize("@ss.checkAdmin()")
    @PutMapping
    public ApiResult edit(@Validated @RequestBody SysMenu menu) {
        if (UserConstants.NOT_UNIQUE.equals(menuService.checkMenuNameUnique(menu))) {
            return ApiResult.error("修改菜单'" + menu.getMenuName() + "'失败，菜单名称已存在");
        } else if (menu.getMenuId().equals(menu.getParentId())) {
            return ApiResult.error("修改菜单'" + menu.getMenuName() + "'失败，上级菜单不能选择自己");
        }
        return toApiResult(menuService.updateById(menu));
    }

    /**
     * 删除菜单
     */
    @PreAuthorize("@ss.checkAdmin()")
    @DeleteMapping("/{menuId}")
    public ApiResult remove(@PathVariable("menuId") Integer menuId) {
        return menuService.remove(menuId);
    }
}