package com.zhiyun.project.system.controller;

import com.zhiyun.common.model.ApiResult;
import com.zhiyun.common.utils.SecurityUtils;
import com.zhiyun.framework.web.TokenService;
import com.zhiyun.project.common.BaseController;
import com.zhiyun.project.system.domain.dto.LoginUser;
import com.zhiyun.project.system.domain.entity.SysUser;
import com.zhiyun.project.system.service.ISysUserService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.HashMap;
import java.util.Map;

/**
 * 个人信息 业务处理
 *
 * @author ruoyi
 */
@RestController
@RequestMapping("/system/user/profile")
public class SysProfileController extends BaseController {
    @Autowired
    private ISysUserService userService;

    @Autowired
    private TokenService tokenService;

    /**
     * 个人信息
     */
    @GetMapping
    public ApiResult profile() {
        LoginUser loginUser = getLoginUser();
        Map<String, Object> result = new HashMap<>();
        result.put("user", loginUser.getUser());
        return ApiResult.success(result);
    }

    /**
     * 重置密码
     */
    @PutMapping("/updatePwd")
    public ApiResult updatePwd(String oldPassword, String newPassword) {
        LoginUser loginUser = getLoginUser();
        Integer userId = loginUser.getUserId();
        String password = loginUser.getPassword();
        if (!SecurityUtils.matchesPassword(oldPassword, password)) {
            return ApiResult.error("修改密码失败，旧密码错误");
        }
        if (SecurityUtils.matchesPassword(newPassword, password)) {
            return ApiResult.error("新密码不能与旧密码相同");
        }
        SysUser user = new SysUser();
        user.setUserId(userId);
        user.setPassword(SecurityUtils.encryptPassword(newPassword));
        if (userService.updateById(user)) {
            // 更新缓存用户密码
            loginUser.getUser().setPassword(SecurityUtils.encryptPassword(newPassword));
            tokenService.setLoginUser(loginUser);
            return ApiResult.success();
        }
        return ApiResult.error("修改密码异常，请联系管理员");
    }
}
