package com.zhiyun.project.system.controller;

import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.zhiyun.common.model.ApiResult;
import com.zhiyun.common.model.TableResult;
import com.zhiyun.common.utils.SecurityUtils;
import com.zhiyun.project.common.BaseController;
import com.zhiyun.project.system.domain.body.SysUserBody;
import com.zhiyun.project.system.domain.entity.SysUser;
import com.zhiyun.project.system.service.ISysUserService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;


/**
 * 用户信息
 *
 * @author ruoyi
 */
@RestController
@RequestMapping("/system/user")
public class SysUserController extends BaseController {
    @Autowired
    private ISysUserService userService;

    /**
     * 获取用户列表
     */
    @GetMapping("/list")
    public TableResult list(SysUserBody body) {
        return TableResult.getTableResult(userService.selectUserPage(body));
    }

    /**
     * 新增用户
     */
    @PreAuthorize("@ss.checkAdmin()")
    @PostMapping
    public ApiResult add(@Validated @RequestBody SysUser user) {
        if (!userService.checkFieldUnique(null, ISysUserService.FIELD_USERNAME, user.getUserName())) {
            return ApiResult.error("新增用户'" + user.getUserName() + "'失败，登录账号已存在");
        }
        user.setPassword(SecurityUtils.encryptPassword(user.getPassword()));
        return toApiResult(userService.save(user));
    }

    /**
     * 修改用户
     */
    @PreAuthorize("@ss.checkAdmin()")
    @PutMapping
    public ApiResult edit(@Validated @RequestBody SysUser user) {
        return toApiResult(userService.updateUser(user));
    }

    /**
     * 删除用户
     */
    @PreAuthorize("@ss.checkAdmin()")
    @DeleteMapping("/{userId}")
    public ApiResult remove(@PathVariable Integer userId) {
        return toApiResult(userService.deleteUserById(userId));
    }

    /**
     * 重置密码
     */
    @PutMapping("/resetPwd")
    public ApiResult resetPwd(@RequestBody SysUser user) {
        if (!user.getUserId().equals(getUserId())) {
            return ApiResult.error("无权限!");
        }
        return toApiResult(userService.update(new UpdateWrapper<SysUser>()
                .set("password", SecurityUtils.encryptPassword(user.getPassword())).eq("user_id", user.getUserId())));
    }

    /**
     * 状态修改
     */
    @PreAuthorize("@ss.checkAdmin()")
    @PutMapping("/changeStatus")
    public ApiResult changeStatus(@RequestBody SysUser user) {
        return toApiResult(userService.update(new UpdateWrapper<SysUser>().set("status", user.getStatus())));
    }

}
