package com.zhiyun.project.system.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.zhiyun.common.utils.DictUtils;
import com.zhiyun.common.utils.StringUtils;
import com.zhiyun.project.system.domain.entity.SysDictData;
import com.zhiyun.project.system.mapper.SysDictMapper;
import com.zhiyun.project.system.service.ISysDictService;
import org.springframework.stereotype.Service;

import javax.annotation.PostConstruct;
import java.util.ArrayList;
import java.util.Comparator;
import java.util.List;
import java.util.stream.Collectors;

/**
 * 字典 业务层处理
 */
@Service
public class SysDictServiceImpl extends ServiceImpl<SysDictMapper, SysDictData> implements ISysDictService {

    /**
     * 项目启动时，初始化字典到缓存
     */
    @PostConstruct
    public void init() {
        loadingDictCache();
    }

    @Override
    public void resetDictCache() {
        //清除缓存
        DictUtils.clearDictCache();
        loadingDictCache();
    }

    @Override
    public List<SysDictData> getDictByType(String dictType) {
        List<SysDictData> dictDatas = DictUtils.getDictCache(dictType);
        if (StringUtils.isNotEmpty(dictDatas)) {
            return dictDatas;
        }
        dictDatas = baseMapper.selectList(new QueryWrapper<SysDictData>().eq("dict_type", dictType));
        if (StringUtils.isNotEmpty(dictDatas)) {
            DictUtils.setDictCache(dictType, dictDatas);
            return dictDatas;
        }
        return new ArrayList<>();
    }

    /**
     * 加载字典缓存数据
     */
    private void loadingDictCache() {
        //筛选全部有效字典数据
        List<SysDictData> dictDataList = baseMapper.selectList(new QueryWrapper<>());
        //保存字典数据
        dictDataList.stream().collect(Collectors.groupingBy(SysDictData::getDictType))
                .forEach((key, value) -> DictUtils.setDictCache(key, value.stream().sorted(Comparator.comparing(SysDictData::getDictSort)).collect(Collectors.toList())));
    }

}
