package com.zhiyun.project.system.service.impl;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.zhiyun.common.constant.UserConstants;
import com.zhiyun.common.enums.MenuSysType;
import com.zhiyun.common.model.ApiResult;
import com.zhiyun.framework.UserDataScope;
import com.zhiyun.project.system.domain.body.SysMenuBody;
import com.zhiyun.project.system.domain.entity.SysMenu;
import com.zhiyun.project.system.domain.vo.SysMenuVo;
import com.zhiyun.project.system.domain.vo.TreeSelect;
import com.zhiyun.project.system.mapper.SysMenuMapper;
import com.zhiyun.project.system.service.ISysMenuService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.*;
import java.util.stream.Collectors;

/**
 * 菜单 业务层处理
 *
 * @author ruoyi
 */
@Service
public class SysMenuServiceImpl extends ServiceImpl<SysMenuMapper, SysMenu> implements ISysMenuService {

    @Override
    public List<SysMenuVo> getMenuList(SysMenuBody body) {
        return baseMapper.queryMenuList(body);
    }

    @Override
    public List<SysMenuVo> getMenusBySysType(String sysType) {
        return baseMapper.queryBySysType(sysType);
    }

    @Override
    public List<SysMenuVo> getMenuTreeByMineId(Integer userId) {
        List<SysMenuVo> menus = baseMapper.queryMenuTreeByMineId(UserDataScope.isAdmin(userId));
        //管理员能看全部
        List<SysMenuVo> tree = new ArrayList<>();
        for (SysMenuVo item : menus) {
            // 一、根据传入的某个父节点ID,遍历该父节点的所有子节点
            if (item.getParentId() == 0) {
                recurveFillChildMenu(menus, item);
                tree.add(item);
            }
        }
        return tree;
    }

    @Override
    public Map<String, Object> getMineMenuTreeSelect(Integer mineId) {
        Map<String, Object> result = new HashMap<>();
        List<SysMenuVo> menus = baseMapper.queryBySysType(MenuSysType.PROJECT.getValue());
        result.put("checkedKeys", baseMapper.getMenuIdsByMineId(mineId));
        result.put("menus", buildMenuTreeSelect(menus));
        return result;
    }

    @Override
    public ApiResult remove(Integer menuId) {
        if (baseMapper.hasChildByMenuId(menuId) >= 0) {
            return ApiResult.warn("存在子菜单,不允许删除");
        }
        return ApiResult.success(removeById(menuId));
    }


    @Override
    public String checkMenuNameUnique(SysMenu menu) {
        long menuId = menu.getMenuId() == null ? -1L : menu.getMenuId();
        Long dbMenuId = baseMapper.checkMenuNameUnique(menu.getMenuName(), menu.getParentId());
        if (dbMenuId != null && dbMenuId != menuId) {
            return UserConstants.NOT_UNIQUE;
        }
        return UserConstants.UNIQUE;
    }

    /**
     * 递归填充子菜单
     *
     * @param allList 全部的菜单
     * @param menu    菜单
     */
    private void recurveFillChildMenu(List<SysMenuVo> allList, SysMenuVo menu) {
        // 得到子节点列表
        List<SysMenuVo> childList = getChildList(allList, menu.getMenuId());
        if (childList.isEmpty()) return;
        menu.setChildren(childList);
        for (SysMenuVo child : childList) {
            recurveFillChildMenu(allList, child);
        }
    }

    /**
     * 得到子节点列表
     */
    private List<SysMenuVo> getChildList(List<SysMenuVo> list, Long parentId) {
        return list.stream().filter(item -> item.getParentId().longValue() == parentId.longValue()).collect(Collectors.toList());
    }

    /**
     * 构建前端所需要下拉树结构
     *
     * @param menus 菜单列表
     * @return 下拉树结构列表
     */
    private List<TreeSelect> buildMenuTreeSelect(List<SysMenuVo> menus) {
        List<SysMenuVo> menuTrees = new ArrayList<>();
        Set<Long> tempSet = menus.stream().map(SysMenuVo::getMenuId).collect(Collectors.toSet());
        for (SysMenuVo menu : menus) {
            // 如果是顶级节点, 遍历该父节点的所有子节点
            if (!tempSet.contains(menu.getParentId())) {
                recurveFillChildMenu(menus, menu);
                menuTrees.add(menu);
            }
        }
        if (menuTrees.isEmpty()) {
            menuTrees = menus;
        }
        return menuTrees.stream().map(TreeSelect::new).collect(Collectors.toList());
    }

}
